Struct nu_isp::Progress [−][src]
pub struct Progress { /* fields omitted */ }Implementations
Create a new Progress structure with a given handler to be called on events.
pub struct Progress { /* fields omitted */ }Create a new Progress structure with a given handler to be called on events.